@@ -1,4 +1,6 @@
-#: N804
+from abc import ABCMeta
+
+#: N804:7:13
 class Foo(object):
     @classmethod
     def mmm(cls, ads):
@@ -14,7 +16,17 @@ class Foo(object):
 
     def __init_subclass(self, ads):
         pass
-#: N804(--classmethod-decorators=clazzy,cool)
+#: Okay(--ignore-names=klass)
+class SpecialConventionCase(object):
+    @classmethod
+    def prepare_meta(klass, root):
+        pass
+#: Okay(--ignore-names=_*)
+class SpecialConventionCase(object):
+    @classmethod
+    def prepare_meta(_class, root):
+        pass
+#: N804:3:14(--classmethod-decorators=clazzy,cool)
 class NewClassIsRequired(object):
     @cool
     def test(self, sy):
@@ -27,6 +39,9 @@ class Meta(type):
 class MetaMethod(type):
     def test(cls):
         pass
+class MetaMethod(ABCMeta):
+    def test(cls):
+        pass
 #: Okay
 class NotMeta(object):
     otherclass = Foo
